const gulp = require('gulp');
const less = require('gulp-less');
const cleanCss = require('gulp-clean-css');
const connect = require('gulp-connect');
const htmlbeautify = require('gulp-html-beautify');
const clean = require('gulp-clean');
const fileInclude = require('gulp-file-include');

const paths = {
  html: './html/**/*.html',
  css: './html/css/**/*.css',
  img: './html/images/**',
  js: './html/js/**',
  less: './html/less/**/*.less'
}

// 清理目标文件夹/文件
gulp.task('clean', async function() {
	await gulp.src('dist')
		.pipe(clean({
			force: true
		}))
});

// 格式化 html
gulp.task('htmlbeautify', async function() {
	await gulp.src('dist/**/*.html')
		.pipe(htmlbeautify({
			indent_size: 2,
			indent_char: ' '
		}))
		.pipe(gulp.dest('dist/'))
});

// 复制html
gulp.task('copyHtml', async function() {
  await gulp.src(paths.html)
    .pipe(fileInclude({
      prefix: '@@',
      basepath: '@file'
    }))
    .pipe(gulp.dest('dist/'))
    .pipe(connect.reload());
});

// 复制css
gulp.task('copyCss', async function() {
  await gulp.src(paths.css)
    .pipe(gulp.dest('dist/css/'))
    .pipe(connect.reload());
});

// 复制img
gulp.task('copyImg', async function() {
  await gulp.src(paths.img)
    .pipe(gulp.dest('dist/images/'))
    .pipe(connect.reload());
});

// 复制js
gulp.task('copyJs', async function() {
  await gulp.src(paths.js)
    .pipe(gulp.dest('dist/js/'))
    .pipe(connect.reload());
});

// less css 预处理
gulp.task('less', async function() {
  await gulp.src(paths.less)
    .pipe(less())
    .pipe(cleanCss())
    .pipe(gulp.dest('dist/css/'))
    .pipe(connect.reload());
});

// connect任务
gulp.task('connect', async function () {
  await connect.server({
    root: 'dist',
    livereload: true
  });
});

// watch任务
gulp.task('watch', async function () {
  await gulp.watch(paths.html, gulp.series('copyHtml'));
  await gulp.watch(paths.css, gulp.series('copyCss'));
  await gulp.watch(paths.img, gulp.series('copyImg'));
  await gulp.watch(paths.js, gulp.series('copyJs'));
  await gulp.watch(paths.less, gulp.series('less'));
});

gulp.task('copy', gulp.parallel('copyHtml', 'copyCss', 'copyImg', 'copyJs'));
gulp.task('default', gulp.series('copy', 'less', 'connect', 'watch'));